@@ -1,5 +1,5 @@
 # PRINCIPAL COMPONENTS ANALYSIS
-#' @include AllClasses.R AllGenerics.R
+#' @include AllGenerics.R
 NULL
 
 #' @export
@@ -193,61 +193,3 @@ setMethod(
     )
   }
 )
-
-#' @export
-#' @rdname predict
-#' @aliases predict,PCA-method
-setMethod(
-  f = "predict",
-  signature = signature(object = "PCA"),
-  definition = function(object, newdata, margin = 1) {
-    # Coerce to matrix
-    if (missing(newdata)) {
-      data <- object@data
-      data <- data[!object@rows@supplement, !object@columns@supplement]
-    } else {
-      data <- as.matrix(newdata)
-    }
-
-    # Get standard coordinates
-    var_mean <- object@center
-    var_sd <- object@scale
-
-    if (margin == 1) {
-      std <- object@columns@standard
-      w <- object@columns@weights
-
-      newdata <- (t(newdata) - var_mean) * w / var_sd
-    }
-    if (margin == 2) {
-      std <- object@rows@standard
-      w <- object@rows@weights
-      j <- ncol(newdata)
-
-      X <- if (all(var_mean == 0)) rep(0, j) else weighted_mean(newdata, w)
-      newdata <- t(t(newdata) - X)
-      Y <- if (all(var_sd == 1)) rep(1, j) else weighted_sd(newdata, w)
-      newdata <- t(t(newdata) / Y)
-      newdata <- newdata * w
-    }
-
-    # Compute principal coordinates
-    coords <- crossprod(newdata, std)
-    coords <- as.data.frame(coords)
-    colnames(coords) <- paste0("F", seq_along(coords))
-    return(coords)
-  }
-)
-
-#' @export
-#' @rdname loadings
-#' @aliases loadings,PCA-method
-setMethod(
-  f = "loadings",
-  signature = signature(x = "PCA"),
-  definition = function(x) {
-    loads <- x@columns@standard
-    class(loads) <- "loadings"
-    return(loads)
-  }
-)
